package p;
public class Z extends A {
	public final int a;
	public final int b;

	public Z(int a, int b) {
		super();
		this.a = a;
		this.b = b;
	}

	public int geta() {
		return a;
	}

	public int getb() {
		return b;
	}
}